@@ -323,9 +323,9 @@ double SequenceStatistics::tajima83(const PolymorphismSequenceContainer& psc, bo
   while (si->hasMoreSites())
   {
     site = si->nextSite();
+    l++;
     if (!SiteTools::isConstant(*site, ignoreUnknown))
     {
-      l++;
       double value = 0.;
       map<int, size_t> count;
       SymbolListTools::getCounts(*site, count);
@@ -731,7 +731,7 @@ unsigned int SequenceStatistics::numberOfSynonymousSubstitutions(const Polymorph
   while (si->hasMoreSites())
   {
     site = si->nextSite();
-    st  += CodonSiteTools::numberOfSubsitutions(*site, gc, freqmin);
+    st  += CodonSiteTools::numberOfSubstitutions(*site, gc, freqmin);
     sns += CodonSiteTools::numberOfNonSynonymousSubstitutions(*site, gc, freqmin);
   }
   return static_cast<unsigned int>(st - sns);
