@@ -89,6 +89,27 @@ public:
     bool gapflag = true,
     bool ignoreUnknown = true);
 
+  /**
+   * @brief Compute the frequency of polymorphic site in an alignment
+   *
+   * The number of polymorphic site is also known as the number of
+   * segregating site @f$S@f$. This number is devided by the number
+   * of callable sites, which dependson the gapflag and ignoreUnknown arguments.
+   *
+   * Gaps are consider as mutations so if you want number of
+   * polymorphic site without gap, set the gapflag parameter to true.
+   *
+   * @param psc a PolymorphismSequenceContainer
+   * @param gapflag a boolean set by default to true if you don't want to
+   * take gap into account
+   * @param ignoreUnknown a boolean set by default to true to ignore
+   * unknown states
+   */
+  static double frequencyOfPolymorphicSites(
+    const PolymorphismSequenceContainer& psc,
+    bool gapflag = true,
+    bool ignoreUnknown = true);
+
   /**
    * @brief Compute the number of parsimony informative sites in an alignment
    *
@@ -136,13 +157,11 @@ public:
    *
    * @param ing a PolymorphismSequenceContainer the ingroup alignement
    * @param outg a PolymorphismSequenceContainer the outgroup alignement
-   * @throw Exception if ing and outg are not of the same size (site number)
    * @author Khalid Belkhir
    */
   static unsigned int totalNumberOfMutationsOnExternalBranches(
     const PolymorphismSequenceContainer& ing,
-    const PolymorphismSequenceContainer& outg)
-  throw (Exception);
+    const PolymorphismSequenceContainer& outg);
 
   /**
    * @brief Compute the number of triplet in an alignment
@@ -216,12 +235,15 @@ public:
    * take gap into account
    * @param ignoreUnknown a boolean set by default to true to ignore
    * unknown states
-   * @author Sylvain Gaillard
+   * @param scaled Tell if theta should be normalized per nucleotide
+   * (divided by the length of the sequence).
+   * @author Sylvain Gaillard, Julien Dutheil
    */
   static double watterson75(
     const PolymorphismSequenceContainer& psc,
     bool gapflag = true,
-    bool ignoreUnknown = true);
+    bool ignoreUnknown = true,
+    bool scaled = false);
 
   /**
    * @brief Compute diversity estimator Theta of Tajima (1983, Genetics, 105 pp437-460)
@@ -238,11 +260,17 @@ public:
    * @param psc a PolymorphismSequenceContainer
    * @param gapflag flag set by default to true if you don't want to
    * take gap into account
-   * @author Sylvain Gaillard
+   * @param ignoreUnknown a boolean set by default to true to ignore
+   * unknown states
+   * @param scaled Tell if theta should be normalized per nucleotide
+   * (divided by the length of the sequence).
+   * @author Sylvain Gaillard, Julien Dutheil
    */
   static double tajima83(
     const PolymorphismSequenceContainer& psc,
-    bool gapflag = true);
+    bool gapflag = true,
+    bool ignoreUnknown = true,
+    bool scaled = false);
 
   /**
    * @brief Compute diversity estimator Theta H (eq. 3) of Fay and Wu (2000, Genetics, 155: 1405-1413)
@@ -313,8 +341,7 @@ public:
    * @author Éric Bazin
    */
   static double ratioOfTransitionsTransversions(
-    const PolymorphismSequenceContainer& psc )
-  throw (Exception);
+    const PolymorphismSequenceContainer& psc);
 
   /**
    * @brief Compute the number of codon sites with stop codon
@@ -585,13 +612,15 @@ public:
    * @param psc a PolymorphismSequenceContainer
    * @param gapflag flag set by default to true if you don't want to
    * take gap into account
+   * @param ignoreUnknown a boolean set by default to true to ignore
+   * unknown states
    * @throw ZeroDivisionException if S == 0
    * @author Sylvain Gaillard
    */
   static double tajimaDss(
     const PolymorphismSequenceContainer& psc,
-    bool gapflag = true)
-  throw (ZeroDivisionException);
+    bool gapflag = true,
+    bool ignoreUnknown = true);
 
   /**
    * @brief Return the Tajima's D test (Tajima 1989, Genetics 123 pp 585-595).
@@ -603,24 +632,29 @@ public:
    * @param psc a PolymorphismSequenceContainer
    * @param gapflag flag set by default to true if you don't want to
    * take gap into account
+   * @param ignoreUnknown a boolean set by default to true to ignore
+   * unknown states
    * @throw ZeroDivisionException if eta == 0
    * @author Sylvain Gaillard
    */
   static double tajimaDtnm(
     const PolymorphismSequenceContainer& psc,
-    bool gapflag = true)
-  throw (ZeroDivisionException);
+    bool gapflag = true,
+    bool ignoreUnknown = true);
 
   /**
    * @brief Return the Fu and Li D test (Fu & Li 1993, Genetics, 133 pp693-709).
    *
    * @param ingroup a PolymorphismSequenceContainer
    * @param outgroup a PolymorphismSequenceContainer
-   * @param original true: use the Fu & Li methode, false: use mutations in
-   * external branch.
+   * @param useNbSingletons use the original Fu & Li method based on the number of singletons, otherwise, use the total number of mutations in
+   * external branches.
+   * @param useNbSegregatingSites use the number of seggregating sites, otherwise use the total number of mutations.
+   * These two quantities are identical under the infinite site model, but the number of segregating sites will underestimate the total number of mutations in case of multiple substitutions at the same site.
    * @throw ZeroDivisionException if eta == 0
    * @author Sylvain Gaillard
    * @author Khalid Belkhir
+   * @author Julien Dutheil
    *
    * If one set original=false then the number of mutations will be used.
    * If the outgroup contains more than one sequence the sites with more
@@ -629,28 +663,35 @@ public:
   static double fuLiD(
     const PolymorphismSequenceContainer& ingroup,
     const PolymorphismSequenceContainer& outgroup,
-    bool original = true)
-  throw (ZeroDivisionException);
+    bool useNbSingletons = true,
+    bool useNbSegregatingSites = false);
 
   /**
    * @brief Return the Fu and Li D<sup>*</sup> test (Fu & Li 1993, Genetics, 133 pp693-709).
    *
    * @param group a PolymorphismSequenceContainer
+   * @param useNbSegregatingSites use the number of seggregating sites, otherwise use the total number of mutations.
+   * These two quantities are identical under the infinite site model, but the number of segregating sites will underestimate the total number of mutations in case of multiple substitutions at the same site.
    * @author Sylvain Gaillard
+   * @author Julien Dutheil
    */
   static double fuLiDStar(
-    const PolymorphismSequenceContainer& group)
-  throw (ZeroDivisionException);
+    const PolymorphismSequenceContainer& group,
+    bool useNbSegregatingSites = false);
 
   /**
    * @brief Return the Fu and Li F test (Fu & Li 1993, Genetics, 133 pp693-709).
    *
    * @param ingroup a PolymorphismSequenceContainer
    * @param outgroup a PolymorphismSequenceContainer
-   * @param original true: use the Fu & Li methode, false: use mutations in
    * external branch.
+   * @param useNbSingletons use the original Fu & Li method based on the number of singletons, otherwise, use the total number of mutations in
+   * external branches.
+   * @param useNbSegregatingSites use the number of seggregating sites, otherwise use the total number of mutations.
+   * These two quantities are identical under the infinite site model, but the number of segregating sites will underestimate the total number of mutations in case of multiple substitutions at the same site.
    * @author Sylvain Gaillard
    * @author Khalid Belkhir
+   * @author Julien Dutheil
    *
    * If one set original=false then the number of mutations will be used.
    * If the outgroup contains more than one sequence the sites with more
@@ -659,18 +700,21 @@ public:
   static double fuLiF(
     const PolymorphismSequenceContainer& ingroup,
     const PolymorphismSequenceContainer& outgroup,
-    bool original = true)
-  throw (ZeroDivisionException);
+    bool useNbSingletons = true,
+    bool useNbSegregatingSites = false);
 
   /**
    * @brief Return the Fu and Li F<sup>*</sup> test (Fu & Li 1993, Genetics, 133 pp693-709).
    *
    * @param group a PolymorphismSequenceContainer
+   * @param useNbSegregatingSites use the number of seggregating sites, otherwise use the total number of mutations.
+   * These two quantities are identical under the infinite site model, but the number of segregating sites will underestimate the total number of mutations in case of multiple substitutions at the same site.
    * @author Sylvain Gaillard
+   * @author Julien Dutheil
    */
   static double fuLiFStar(
-    const PolymorphismSequenceContainer& group)
-  throw (ZeroDivisionException);
+    const PolymorphismSequenceContainer& group,
+    bool useNbSegregatingSites);
 
   /**
    * Fst of Hudson, Slatkin and Maddison
@@ -743,8 +787,7 @@ public:
   static Vdouble pairwiseDistances1(
     const PolymorphismSequenceContainer& psc,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give the vector of all mean pairwise distance between two sites to a LD SequencePolymorphismContainer
@@ -763,8 +806,7 @@ public:
   static Vdouble pairwiseDistances2(
     const PolymorphismSequenceContainer& psc,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give the vector of all mean pairwise D value between two sites (Lewontin & Kojima 1964, Evolution 14 pp458-472)
@@ -781,8 +823,7 @@ public:
   static Vdouble pairwiseD(
     const PolymorphismSequenceContainer& psc,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give the vector of all mean pairwise D' value between two sites (Lewontin 1964, Genetics 49 pp49-67))
@@ -799,8 +840,7 @@ public:
   static Vdouble pairwiseDprime(
     const PolymorphismSequenceContainer& psc,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give the vector of all mean pairwise R² value between two sites (Hill & Robertson 1968, Theor. Appl. Genet., 38 pp226-231)
@@ -817,8 +857,7 @@ public:
   static Vdouble pairwiseR2(
     const PolymorphismSequenceContainer& psc,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give mean D over all pairwise comparisons
@@ -835,8 +874,7 @@ public:
   static double meanD(
     const PolymorphismSequenceContainer& psc,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give mean D' over all pairwise comparisons
@@ -853,8 +891,7 @@ public:
   static double meanDprime(
     const PolymorphismSequenceContainer& psc,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give mean R² over all pairwise comparisons
@@ -871,8 +908,7 @@ public:
   static double meanR2(
     const PolymorphismSequenceContainer& psc,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give mean pairwise distances between sites / method 1: differences between sequences are not taken into account
@@ -888,8 +924,7 @@ public:
   static double meanDistance1(
     const PolymorphismSequenceContainer& psc,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give mean pairwise distances between sites / method 2: differences between sequences are taken into account
@@ -905,8 +940,7 @@ public:
   static double meanDistance2(
     const PolymorphismSequenceContainer& psc,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give the slope of the regression |D| = 1+a*distance
@@ -928,8 +962,7 @@ public:
     const PolymorphismSequenceContainer& psc,
     bool distance1 = false,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give the slope of the regression |D'| = 1+a*distance
@@ -951,8 +984,7 @@ public:
     const PolymorphismSequenceContainer& psc,
     bool distance1 = false,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give the slope of the regression R² = 1+a*distance
@@ -974,8 +1006,7 @@ public:
     const PolymorphismSequenceContainer& psc,
     bool distance1 = false,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give the slope and the origin of the regression |D| = a*distance+b
@@ -997,8 +1028,7 @@ public:
     const PolymorphismSequenceContainer& psc,
     bool distance1 = false,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give the slope and the origin of the regression |D'| = a*distance+b
@@ -1020,7 +1050,7 @@ public:
     const PolymorphismSequenceContainer& psc,
     bool distance1 = false,
     bool keepsingleton = true,
-    double freqmin = 0.) throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give the slope and the origin of the regression R² = a*distance+b
@@ -1042,8 +1072,7 @@ public:
     const PolymorphismSequenceContainer& psc,
     bool distance1 = false,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give the slope of the regression R² = 1/(1+a*distance)
@@ -1066,8 +1095,7 @@ public:
     const PolymorphismSequenceContainer& psc,
     bool distance1 = false,
     bool keepsingleton = true,
-    double freqmin = 0.)
-  throw (DimensionException);
+    double freqmin = 0.);
 
   /**
    * @brief give estimate of C=4Nr using Hudson method (Hudson 1987, Genet. Res., 50 pp245-250)
